@@ -10,13 +10,13 @@ class InternalError(Error):
 class ToolError(Error):
     """An external tool indicated an error"""
     def __init__(self, program, message=None):
-        super(ToolError,self).__init__(message or "'{}' failed".format(program))
+        super().__init__(message or "'{}' failed".format(program))
         self.program = program
 
 class MissingToolError(Error):
     """A required external tool is missing"""
     def __init__(self, program, package):
-        super(MissingToolError, self).__init__("Couldn't find '{}'. Is '{}' installed?".format(
+        super().__init__("Couldn't find '{}'. Is '{}' installed?".format(
             program, package))
         self.program = program
         self.package = package
@@ -36,7 +36,7 @@ class ArchiveError(Error):
 class LibExistsError(ArchiveError):
     """Given library already exists in archive"""
     def __init__(self, lib):
-        super(LibExistsError, self).__init__(
+        super().__init__(
                 "Library '{}' already exists in archive".format(lib))
         self.lib = lib
 
@@ -44,6 +44,6 @@ class LibExistsError(ArchiveError):
 class DirectoryExistsError(Error):
     """A given directory already exists"""
     def __init__(self, path):
-        super(DirectoryExistsError, self).__init__(
+        super().__init__(
                 "{}: is a directory".format(path))
         self.path = path
